==> tuxguitar_1.0.orig.tar.gz: tuxguitar-src-1.0/TuxGuitar/src/org/herac/tuxguitar/gui/system/config/TGConfigKeys.java <==
/*
 * Created on 27-ene-2006
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.system.config;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class TGConfigKeys {
	public static final String SKIN = "skin";
	public static final String WINDOW_TITLE = "window.title";
	public static final String SHOW_SPLASH = "show.splash";
	public static final String MAXIMIZED = "window.maximized";
	public static final String WIDTH = "window.width";
	public static final String HEIGHT = "window.height";
	public static final String SHOW_MIXER = "show.mixer";
	public static final String SHOW_TRANSPORT = "show.transport";
	public static final String SHOW_FRETBOARD = "show.fretboard";
	public static final String SHOW_MATRIX = "show.matrix";
	public static final String SHOW_PIANO = "show.piano";
	public static final String SHOW_MARKERS = "show.markers";
	public static final String LAYOUT_MODE = "layout.mode";
	public static final String LAYOUT_STYLE = "layout.style";
	public static final String LAYOUT_PAGE_FORCE_WIDTH = "layout.page.force-width";
	public static final String LANGUAGE = "language";
	public static final String EDITOR_MOUSE_MODE = "editor.mouse.mode";
	public static final String EDITOR_NATURAL_KEY_MODE = "editor.natural.key.mode";
	public static final String FONT_DEFAULT = "font.default";
	public static final String FONT_NOTE = "font.note";
	public static final String FONT_TIME_SIGNATURE = "font.time-signature";
	public static final String FONT_CHORD = "font.chord";
	public static final String FONT_CHORD_FRET = "font.chord-fret";
	public static final String FONT_GRACE = "font.grace";
	public static final String FONT_LYRIC = "font.lyric";
	public static final String FONT_TEXT = "font.text";
	public static final String FONT_PRINTER_DEFAULT = "font.printer.default";
	public static final String FONT_PRINTER_NOTE = "font.printer.note";
	public static final String FONT_PRINTER_TIME_SIGNATURE = "font.printer.time-signature";
	public static final String FONT_PRINTER_LYRIC = "font.printer.lyric";
	public static final String FONT_PRINTER_TEXT = "font.printer.text";
	public static final String FONT_PRINTER_CHORD = "font.printer.chord";
	public static final String FONT_PRINTER_GRACE = "font.printer.grace";
	public static final String FONT_ABOUT_DIALOG_TITLE = "font.about.dialog.title";
	public static final String COLOR_BACKGROUND = "color.background";
	public static final String COLOR_LINE = "color.line";
	public static final String COLOR_SCORE_NOTE = "color.score.note";
	public static final String COLOR_TAB_NOTE = "color.tab.note";
	public static final String COLOR_PLAY_NOTE = "color.play.note";
	public static final String MIDI_PORT = "midi.port";
	public static final String MIDI_SEQUENCER = "midi.sequencer";
	public static final String MAX_HISTORY_FILES = "history.max-files";
	public static final String MIN_SCORE_TABLATURE_SPACING = "score.min.score-tab-spacing";
	public static final String SCORE_LINE_SPACING = "score.line-spacing";
	public static final String TAB_LINE_SPACING = "tab.line-spacing";
	public static final String FIRST_TRACK_SPACING = "first-track.spacing";
	public static final String TRACK_SPACING = "track.spacing";
	public static final String FRETBOARD_STRING_SPACING = "fretboard.string-spacing";
	public static final String FRETBOARD_STYLE = "fretboard.style";
	public static final String FRETBOARD_FONT = "fretboard.font";
	public static final String FRETBOARD_COLOR_BACKGROUND = "fretboard.color.background";
	public static final String FRETBOARD_COLOR_STRING = "fretboard.color.string";
	public static final String FRETBOARD_COLOR_FRET_POINT = "fretboard.color.fret-point";
	public static final String FRETBOARD_COLOR_NOTE = "fretboard.color.note";
	public static final String FRETBOARD_COLOR_SCALE = "fretboard.color.scale";
	public static final String PIANO_COLOR_KEY_NATURAL = "piano.color.natural-key";
	public static final String PIANO_COLOR_KEY_NOT_NATURAL = "piano.color.not-natural-key";
	public static final String PIANO_COLOR_NOTE = "piano.color.note";
	public static final String PIANO_COLOR_SCALE = "piano.color.scale";
	public static final String MATRIX_GRIDS = "matrix.grids";
	public static final String MATRIX_FONT = "matrix.font";
	public static final String MATRIX_COLOR_FOREGROUND = "matrix.color.foreground";
	public static final String MATRIX_COLOR_LINE_1= "matrix.color.line-1";
	public static final String MATRIX_COLOR_LINE_2= "matrix.color.line-2";
	public static final String MATRIX_COLOR_LINE_3= "matrix.color.line-3";
	public static final String MATRIX_COLOR_BORDER = "matrix.color.border";
	public static final String MATRIX_COLOR_POSITION = "matrix.color.position";
	public static final String MATRIX_COLOR_NOTE = "matrix.color.note";
	public static final String MATRIX_COLOR_PLAY_NOTE = "matrix.color.play-note";
	public static final String TABLE_AUTO_SIZE = "table.auto-size";
	public static final String BROWSER_LINES_VISIBLE = "browser.lines-visible";
	public static final String SYSTEM_PLAYER = "system.player";
	public static final String FORCE_OS_DEFAULTS = "painter.force-os-defaults";
}

==> tuxguitar_1.1.orig.tar.gz: tuxguitar-src-1.1/TuxGuitar/src/org/herac/tuxguitar/gui/system/config/TGConfigKeys.java <==
/*
 * Created on 27-ene-2006
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.system.config;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class TGConfigKeys {
	public static final String SKIN = "skin";
	public static final String WINDOW_TITLE = "window.title";
	public static final String SHOW_SPLASH = "show.splash";
	public static final String MAXIMIZED = "window.maximized";
	public static final String WIDTH = "window.width";
	public static final String HEIGHT = "window.height";
	public static final String SHOW_MIXER = "show.mixer";
	public static final String SHOW_TRANSPORT = "show.transport";
	public static final String SHOW_FRETBOARD = "show.fretboard";
	public static final String SHOW_MATRIX = "show.matrix";
	public static final String SHOW_PIANO = "show.piano";
	public static final String SHOW_MARKERS = "show.markers";
	public static final String LAYOUT_MODE = "layout.mode";
	public static final String LAYOUT_STYLE = "layout.style";
	public static final String LAYOUT_PAGE_FORCE_WIDTH = "layout.page.force-width";
	public static final String LANGUAGE = "language";
	public static final String EDITOR_MOUSE_MODE = "editor.mouse.mode";
	public static final String EDITOR_NATURAL_KEY_MODE = "editor.natural.key.mode";
	public static final String FONT_DEFAULT = "font.default";
	public static final String FONT_NOTE = "font.note";
	public static final String FONT_TIME_SIGNATURE = "font.time-signature";
	public static final String FONT_CHORD = "font.chord";
	public static final String FONT_CHORD_FRET = "font.chord-fret";
	public static final String FONT_GRACE = "font.grace";
	public static final String FONT_LYRIC = "font.lyric";
	public static final String FONT_TEXT = "font.text";
	public static final String FONT_MARKER = "font.marker";
	public static final String FONT_PRINTER_DEFAULT = "font.printer.default";
	public static final String FONT_PRINTER_NOTE = "font.printer.note";
	public static final String FONT_PRINTER_TIME_SIGNATURE = "font.printer.time-signature";
	public static final String FONT_PRINTER_LYRIC = "font.printer.lyric";
	public static final String FONT_PRINTER_TEXT = "font.printer.text";
	public static final String FONT_PRINTER_CHORD = "font.printer.chord";
	public static final String FONT_PRINTER_GRACE = "font.printer.grace";
	public static final String FONT_ABOUT_DIALOG_TITLE = "font.about.dialog.title";
	public static final String COLOR_BACKGROUND = "color.background";
	public static final String COLOR_LINE = "color.line";
	public static final String COLOR_SCORE_NOTE = "color.score.note";
	public static final String COLOR_TAB_NOTE = "color.tab.note";
	public static final String COLOR_PLAY_NOTE = "color.play.note";
	public static final String COLOR_CARET_1 = "color.caret.1";
	public static final String COLOR_CARET_2 = "color.caret.2";
	public static final String MIDI_PORT = "midi.port";
	public static final String MIDI_SEQUENCER = "midi.sequencer";
	public static final String MAX_HISTORY_FILES = "history.max-files";
	public static final String MIN_SCORE_TABLATURE_SPACING = "score.min.score-tab-spacing";
	public static final String SCORE_LINE_SPACING = "score.line-spacing";
	public static final String TAB_LINE_SPACING = "tab.line-spacing";
	public static final String FIRST_TRACK_SPACING = "first-track.spacing";
	public static final String TRACK_SPACING = "track.spacing";
	public static final String FRETBOARD_STRING_SPACING = "fretboard.string-spacing";
	public static final String FRETBOARD_STYLE = "fretboard.style";
	public static final String FRETBOARD_FONT = "fretboard.font";
	public static final String FRETBOARD_COLOR_BACKGROUND = "fretboard.color.background";
	public static final String FRETBOARD_COLOR_STRING = "fretboard.color.string";
	public static final String FRETBOARD_COLOR_FRET_POINT = "fretboard.color.fret-point";
	public static final String FRETBOARD_COLOR_NOTE = "fretboard.color.note";
	public static final String FRETBOARD_COLOR_SCALE = "fretboard.color.scale";
	public static final String PIANO_COLOR_KEY_NATURAL = "piano.color.natural-key";
	public static final String PIANO_COLOR_KEY_NOT_NATURAL = "piano.color.not-natural-key";
	public static final String PIANO_COLOR_NOTE = "piano.color.note";
	public static final String PIANO_COLOR_SCALE = "piano.color.scale";
	public static final String MATRIX_GRIDS = "matrix.grids";
	public static final String MATRIX_FONT = "matrix.font";
	public static final String MATRIX_COLOR_FOREGROUND = "matrix.color.foreground";
	public static final String MATRIX_COLOR_LINE_1= "matrix.color.line-1";
	public static final String MATRIX_COLOR_LINE_2= "matrix.color.line-2";
	public static final String MATRIX_COLOR_LINE_3= "matrix.color.line-3";
	public static final String MATRIX_COLOR_BORDER = "matrix.color.border";
	public static final String MATRIX_COLOR_POSITION = "matrix.color.position";
	public static final String MATRIX_COLOR_NOTE = "matrix.color.note";
	public static final String MATRIX_COLOR_PLAY_NOTE = "matrix.color.play-note";
	public static final String TABLE_AUTO_SIZE = "table.auto-size";
	public static final String BROWSER_LINES_VISIBLE = "browser.lines-visible";
	public static final String SYSTEM_PLAYER = "system.player";
	public static final String FORCE_OS_DEFAULTS = "painter.force-os-defaults";
}
